@@ -80,7 +80,7 @@ del _configure_system
 
 # Replaced with the current commit when building the wheels.
 __commit__ = "{{RAY_COMMIT_SHA}}"
-__version__ = "1.9.2"
+__version__ = "1.10.0"
 
 import ray._raylet  # noqa: E402
 
@@ -123,7 +123,7 @@ __all__ = [
     "client",
     "ClientBuilder",
     "cluster_resources",
-    "data"
+    "data",
     "get",
     "get_actor",
     "get_gpu_ids",
